package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Sep 17, 2025
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
ConfigDir string `mapstructure:"config_dir"`
DBPath string `mapstructure:"db_path"`
LogPath string `mapstructure:"log_path"`
TimeLayout string `mapstructure:"time_layout"`
DateLayout string `mapstructure:"date_layout"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.